@@ -7,8 +7,8 @@ sys.path.append('..')
 import geoip2
 import requests_mock
 from geoip2.errors import (AddressNotFoundError, AuthenticationError,
-                           GeoIP2Error, HTTPError, InvalidRequestError, OutOfQueriesError,
-                           PermissionRequiredError)
+                           GeoIP2Error, HTTPError, InvalidRequestError,
+                           OutOfQueriesError, PermissionRequiredError)
 from geoip2.webservice import Client
 
 if sys.version_info[:2] == (2, 6):
@@ -22,22 +22,31 @@ if sys.version_info[0] == 2:
 
 
 class TestClient(unittest.TestCase):
-
     def setUp(self):
         self.client = Client(42, 'abcdef123456')
 
     base_uri = 'https://geoip.maxmind.com/geoip/v2.1/'
     country = {
-        'continent': {'code': 'NA',
-                      'geoname_id': 42,
-                      'names': {'en': 'North America'}},
+        'continent': {
+            'code': 'NA',
+            'geoname_id': 42,
+            'names': {
+                'en': 'North America'
+            }
+        },
         'country': {
             'geoname_id': 1,
             'iso_code': 'US',
-            'names': {'en': 'United States of America'}
+            'names': {
+                'en': 'United States of America'
+            }
+        },
+        'maxmind': {
+            'queries_remaining': 11
+        },
+        'traits': {
+            'ip_address': '1.2.3.4'
         },
-        'maxmind': {'queries_remaining': 11},
-        'traits': {'ip_address': '1.2.3.4'},
     }
 
     def _content_type(self, endpoint):
@@ -46,10 +55,11 @@ class TestClient(unittest.TestCase):
 
     @requests_mock.mock()
     def test_country_ok(self, mock):
-        mock.get(self.base_uri + 'country/1.2.3.4',
-                 json=self.country,
-                 status_code=200,
-                 headers={'Content-Type': self._content_type('country')})
+        mock.get(
+            self.base_uri + 'country/1.2.3.4',
+            json=self.country,
+            status_code=200,
+            headers={'Content-Type': self._content_type('country')})
         country = self.client.country('1.2.3.4')
         self.assertEqual(
             type(country), geoip2.models.Country,
@@ -73,10 +83,11 @@ class TestClient(unittest.TestCase):
 
     @requests_mock.mock()
     def test_me(self, mock):
-        mock.get(self.base_uri + 'country/me',
-                 json=self.country,
-                 status_code=200,
-                 headers={'Content-Type': self._content_type('country')})
+        mock.get(
+            self.base_uri + 'country/me',
+            json=self.country,
+            status_code=200,
+            headers={'Content-Type': self._content_type('country')})
         implicit_me = self.client.country()
         self.assertEqual(
             type(implicit_me), geoip2.models.Country,
@@ -88,9 +99,10 @@ class TestClient(unittest.TestCase):
 
     @requests_mock.mock()
     def test_200_error(self, mock):
-        mock.get(self.base_uri + 'country/1.1.1.1',
-                 status_code=200,
-                 headers={'Content-Type': self._content_type('country')})
+        mock.get(
+            self.base_uri + 'country/1.1.1.1',
+            status_code=200,
+            headers={'Content-Type': self._content_type('country')})
         with self.assertRaisesRegex(GeoIP2Error,
                                     'could not decode the response as JSON'):
             self.client.country('1.1.1.1')
@@ -103,20 +115,22 @@ class TestClient(unittest.TestCase):
 
     @requests_mock.mock()
     def test_no_body_error(self, mock):
-        mock.get(self.base_uri + 'country/' + '1.2.3.7',
-                 text='',
-                 status_code=400,
-                 headers={'Content-Type': self._content_type('country')})
+        mock.get(
+            self.base_uri + 'country/' + '1.2.3.7',
+            text='',
+            status_code=400,
+            headers={'Content-Type': self._content_type('country')})
         with self.assertRaisesRegex(
                 HTTPError, 'Received a 400 error for .* with no body'):
             self.client.country('1.2.3.7')
 
     @requests_mock.mock()
     def test_weird_body_error(self, mock):
-        mock.get(self.base_uri + 'country/' + '1.2.3.8',
-                 text='{"wierd": 42}',
-                 status_code=400,
-                 headers={'Content-Type': self._content_type('country')})
+        mock.get(
+            self.base_uri + 'country/' + '1.2.3.8',
+            text='{"wierd": 42}',
+            status_code=400,
+            headers={'Content-Type': self._content_type('country')})
         with self.assertRaisesRegex(HTTPError,
                                     'Response contains JSON but it does not '
                                     'specify code or error keys'):
@@ -124,10 +138,11 @@ class TestClient(unittest.TestCase):
 
     @requests_mock.mock()
     def test_bad_body_error(self, mock):
-        mock.get(self.base_uri + 'country/' + '1.2.3.9',
-                 text='bad body',
-                 status_code=400,
-                 headers={'Content-Type': self._content_type('country')})
+        mock.get(
+            self.base_uri + 'country/' + '1.2.3.9',
+            text='bad body',
+            status_code=400,
+            headers={'Content-Type': self._content_type('country')})
         with self.assertRaisesRegex(
                 HTTPError, 'it did not include the expected JSON body'):
             self.client.country('1.2.3.9')
@@ -141,9 +156,10 @@ class TestClient(unittest.TestCase):
 
     @requests_mock.mock()
     def test_300_error(self, mock):
-        mock.get(self.base_uri + 'country/' + '1.2.3.11',
-                 status_code=300,
-                 headers={'Content-Type': self._content_type('country')})
+        mock.get(
+            self.base_uri + 'country/' + '1.2.3.11',
+            status_code=300,
+            headers={'Content-Type': self._content_type('country')})
         with self.assertRaisesRegex(HTTPError,
                                     'Received a very surprising HTTP status '
                                     '\(300\) for'):
@@ -194,10 +210,11 @@ class TestClient(unittest.TestCase):
     def _test_error(self, mock, status, error_code, error_class):
         msg = 'Some error message'
         body = {'error': msg, 'code': error_code}
-        mock.get(self.base_uri + 'country/1.2.3.18',
-                 json=body,
-                 status_code=status,
-                 headers={'Content-Type': self._content_type('country')})
+        mock.get(
+            self.base_uri + 'country/1.2.3.18',
+            json=body,
+            status_code=status,
+            headers={'Content-Type': self._content_type('country')})
         with self.assertRaisesRegex(error_class, msg):
             self.client.country('1.2.3.18')
 
@@ -206,19 +223,21 @@ class TestClient(unittest.TestCase):
         msg = 'Unknown error type'
         ip = '1.2.3.19'
         body = {'error': msg, 'code': 'UNKNOWN_TYPE'}
-        mock.get(self.base_uri + 'country/' + ip,
-                 json=body,
-                 status_code=400,
-                 headers={'Content-Type': self._content_type('country')})
+        mock.get(
+            self.base_uri + 'country/' + ip,
+            json=body,
+            status_code=400,
+            headers={'Content-Type': self._content_type('country')})
         with self.assertRaisesRegex(InvalidRequestError, msg):
             self.client.country(ip)
 
     @requests_mock.mock()
     def test_request(self, mock):
-        mock.get(self.base_uri + 'country/' + '1.2.3.4',
-                 json=self.country,
-                 status_code=200,
-                 headers={'Content-Type': self._content_type('country')})
+        mock.get(
+            self.base_uri + 'country/' + '1.2.3.4',
+            json=self.country,
+            status_code=200,
+            headers={'Content-Type': self._content_type('country')})
         self.client.country('1.2.3.4')
         request = mock.request_history[-1]
 
@@ -233,20 +252,22 @@ class TestClient(unittest.TestCase):
 
     @requests_mock.mock()
     def test_city_ok(self, mock):
-        mock.get(self.base_uri + 'city/' + '1.2.3.4',
-                 json=self.country,
-                 status_code=200,
-                 headers={'Content-Type': self._content_type('city')})
+        mock.get(
+            self.base_uri + 'city/' + '1.2.3.4',
+            json=self.country,
+            status_code=200,
+            headers={'Content-Type': self._content_type('city')})
         city = self.client.city('1.2.3.4')
         self.assertEqual(
             type(city), geoip2.models.City, 'return value of client.city')
 
     @requests_mock.mock()
     def test_insights_ok(self, mock):
-        mock.get(self.base_uri + 'insights/1.2.3.4',
-                 json=self.country,
-                 status_code=200,
-                 headers={'Content-Type': self._content_type('country')})
+        mock.get(
+            self.base_uri + 'insights/1.2.3.4',
+            json=self.country,
+            status_code=200,
+            headers={'Content-Type': self._content_type('country')})
         insights = self.client.insights('1.2.3.4')
         self.assertEqual(
             type(insights), geoip2.models.Insights,
